@@ -10,7 +10,7 @@ use Bat::Interpreter::Delegate::FileStore::LocalFileSystem;
 use Bat::Interpreter::Delegate::Executor::PartialDryRunner;
 use namespace::autoclean;
 
-our $VERSION = '0.002';    # VERSION
+our $VERSION = '0.003';    # VERSION
 
 =encoding utf-8
 
@@ -188,13 +188,23 @@ sub _handle_special_command {
     my ($type) = keys %$special_command_line;
 
     if ( $type eq 'If' ) {
-        my ( $condition, $statement ) = @{ $special_command_line->{'If'} }{ 'Condition', 'Statement' };
+        my $condition;
+        my $statement;
+        if ( exists $special_command_line->{$type}->{'NegatedCondition'} ) {
+            $condition = $special_command_line->{$type}->{'NegatedCondition'}->{'Condition'};
+            $statement = $special_command_line->{$type}->{'Statement'};
+            if ( not $self->_handle_condition( $condition, $context ) ) {
+                $self->_handle_statement( $statement, $context );
+            }
+        } else {
+            ( $condition, $statement ) = @{ $special_command_line->{'If'} }{ 'Condition', 'Statement' };
+            if ( $self->_handle_condition( $condition, $context ) ) {
 
-        if ( $self->_handle_condition( $condition, $context ) ) {
-
-            #print "True: " . Dumper($statement);
-            $self->_handle_statement( $statement, $context );
+                #print "True: " . Dumper($statement);
+                $self->_handle_statement( $statement, $context );
+            }
         }
+
     }
 
     if ( $type eq 'Goto' ) {
